@@ -1,5 +1,5 @@
 package POE::Component::Client::NTP;
-$POE::Component::Client::NTP::VERSION = '0.12';
+$POE::Component::Client::NTP::VERSION = '0.14';
 #ABSTRACT: A POE Component to query NTP servers
 
 use strict;
@@ -236,6 +236,10 @@ sub _get_datagram {
   @tmp_pkt{@ntp_fields} =
       unpack( "a C3   n B16 n B16 H8   N B32 N B32   N B32 N B32", $data );
 
+  $packet{hex_ref_time} = sprintf '%x.%x', $tmp_pkt{ref_time}, substr +( split m!\.!, $bin2frac->($tmp_pkt{ref_time_fb}) )[1], 0, 9;
+  $packet{hex_org_time} = sprintf '%x.%x', ( $tmp_pkt{org_time} + NTP_ADJ ), substr +( split m!\.!, $bin2frac->($tmp_pkt{org_time_fb}) )[1], 0, 9;
+  $packet{hex_trans_time} = sprintf '%x.%x', $tmp_pkt{trans_time}, substr +( split m!\.!, $bin2frac->($tmp_pkt{trans_time_fb}) )[1], 0, 9;
+
   @packet{@ntp_packet_fields} = (
         (unpack( "C", $tmp_pkt{byte1} & "\xC0" ) >> 6),
         (unpack( "C", $tmp_pkt{byte1} & "\x38" ) >> 3),
@@ -294,7 +298,7 @@ POE::Component::Client::NTP - A POE Component to query NTP servers
 
 =head1 VERSION
 
-version 0.12
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -368,23 +372,31 @@ This is generated by the poco. C<ARG0> will be a hash reference with the followi
   'context', whatever was passed to the constructor;
 
 The C<response> hashref will contain various parts of the NTP response packet as outlined in RFC1305.
-Like L<Net::NTP> some of the data will be normalised/humanised, such as timestamps are in epoch, NOT hexidecimal.
+Like L<Net::NTP> some of the data will be normalised/humanised, such as timestamps are in epoch, NOT hexadecimal.
+
+Hexadecimal timestamps are available for Reference, Originate and Transmit as C<hex_ref_time>, C<hex_org_time> and
+C<hex_trans_time>, respectively.
 
 An example:
 
-          'Root Delay' => '0.001220703125',
-          'Version Number' => 3,
-          'Precision' => -19,
-          'Leap Indicator' => 0,
-          'Transmit Timestamp' => '1239808045.86401',
-          'Receive Timestamp' => '1239808045.86398',
-          'Stratum' => 2,
-          'Originate Timestamp' => '1239808045.24414',
-          'Reference Timestamp' => '1239807468.92445',
-          'Poll Interval' => '0.0000',
-          'Reference Clock Identifier' => '193.79.237.14',
-          'Mode' => 4,
-          'Root Dispersion' => '0.0000'
+   'Version Number' => 3,
+   'Mode' => 4,
+   'Stratum' => 3,
+   'Poll Interval' => '3.0000',
+   'Reference Clock Identifier' => '46.254.216.9'
+   'Precision' => -21,
+   'Root Delay' => '0.0540924072265625',
+   'Delay' => '0.01513',
+   'Leap Indicator' => 0,
+   'Root Dispersion' => '0.0000',
+   'Originate Timestamp' => '1423758184.59018',
+   'Transmit Timestamp' => '1423758184.17864',
+   'Receive Timestamp' => '1423758184.17854',
+   'Reference Timestamp' => '1423757055.50512',
+   'Offset' => '-0.00148022174835205',
+   'hex_org_time' => 'd88751e8.232d70e5',
+   'hex_trans_time' => 'd88751e8.aa5e272',
+   'hex_ref_time' => 'd8874d7f.1e1b7956',
 
 =head1 SEE ALSO
 
